from langchain_core.document_loaders import BaseLoader


class WatsonSpeechToTextLoader(BaseLoader):
    """Transcribe audio ducuments using IBM Watson Speech-to-Text.

    References:
        [1] https://www.ibm.com/products/speech-to-text
        [2] https://cloud.ibm.com/apidocs/speech-to-text?code=python
    """

    pass
