from langchain_core.retrievers import BaseRetriever


class WatsonDiscoveryRetriever(BaseRetriever):
    """IBM Watson Discovery retriever.

    References:
        [1] https://www.ibm.com/products/watson-discovery
        [2] https://cloud.ibm.com/apidocs/discovery-data?code=python
    """

    pass
