from langchain_core.documents import BaseDocumentTransformer


class WatsonLanguageTranslatorTransformer(BaseDocumentTransformer):
    """Translate text documents using IBM Watson Language Translator.

    References:
        [1] https://cloud.ibm.com/apidocs/language-translator?code=python
    """

    pass
