from langchain_core.tools import BaseTool


class WatsonTextToSpeechTool(BaseTool):
    """Tool that queries the IBM Watson Text-to-Speech API.

    References:
        [1] https://www.ibm.com/products/text-to-speech
        [2] https://cloud.ibm.com/apidocs/text-to-speech?code=python
    """

    pass
